@@ -66,11 +66,6 @@ class AgentManager : public QObject, protected QDBusContext
      */
     void cleanup();
 
-     /**
-     * Returns the path of the config file.
-     */
-    static QString configPath( bool writeable );
-
   public Q_SLOTS:
     /**
      * Returns the list of identifiers of all available
@@ -196,7 +191,7 @@ class AgentManager : public QObject, protected QDBusContext
 
     /**
       Trigger a synchronization of the given collection by its owning resource agent.
-      @param recursive set it true to have sub-collection syncronized as well
+      @param recursive set it true to have sub-collection synchronized as well
     */
     void agentInstanceSynchronizeCollection( const QString &identifier, qint64 collection, bool recursive );
 
