@@ -20,11 +20,11 @@
 #include "agentmanager.h"
 #include "controlmanager.h"
 #include "processcontrol.h"
+
 #include "akapplication.h"
 #include "akcrash.h"
 #include "akdebug.h"
-
-#include "protocol_p.h"
+#include "akdbus.h"
 
 #include <QtCore/QCoreApplication>
 #include <QtDBus/QDBusConnection>
@@ -48,23 +48,23 @@ void crashHandler( int )
 
 int main( int argc, char **argv )
 {
-  AkApplication app( argc, argv );
+  AkCoreApplication app( argc, argv );
   app.setDescription( QLatin1String("Akonadi Control Process\nDo not run this manually, use 'akonadictl' instead to start/stop Akonadi.") );
   app.parseCommandLine();
 
   // try to acquire the lock first, that means there is no second instance trying to start up at the same time
   // registering the real service name happens in AgentManager::continueStartup(), when everything is in fact up and running
-  if ( !QDBusConnection::sessionBus().registerService( QLatin1String(AKONADI_DBUS_CONTROL_SERVICE_LOCK) ) ) {
+  if ( !QDBusConnection::sessionBus().registerService( AkDBus::serviceName(AkDBus::ControlLock) ) ) {
     // We couldn't register. Most likely, it's already running.
     const QString lastError = QDBusConnection::sessionBus().lastError().message();
     if (lastError.isEmpty())
-      akFatal() << "Unable to register service as" << AKONADI_DBUS_CONTROL_SERVICE_LOCK << "Maybe it's already running?";
+      akFatal() << "Unable to register service as" << AkDBus::serviceName(AkDBus::ControlLock) << "Maybe it's already running?";
     else
-      akFatal() << "Unable to register service as" << AKONADI_DBUS_CONTROL_SERVICE_LOCK << "Error was:" << lastError;
+      akFatal() << "Unable to register service as" << AkDBus::serviceName(AkDBus::ControlLock) << "Error was:" << lastError;
   }
 
   // older Akonadi server versions don't use the lock service yet, so check if one is already running before we try to start another one
-  if ( QDBusConnection::sessionBus().interface()->isServiceRegistered( QLatin1String(AKONADI_DBUS_CONTROL_SERVICE) ) )
+  if ( QDBusConnection::sessionBus().interface()->isServiceRegistered( AkDBus::serviceName(AkDBus::Control) ) )
     akFatal() << "Another Akonadi control process is already running.";
 
   new ControlManager;
