@@ -30,6 +30,7 @@
 #include <QtNetwork/QLocalServer>
 #endif
 
+class StorageJanitorThread;
 class QProcess;
 class IntervalCheck;
 
@@ -82,6 +83,7 @@ class AkonadiServer: public QLocalServer
 
     CacheCleaner *mCacheCleaner;
     IntervalCheck *mIntervalChecker;
+    StorageJanitorThread *mStorageJanitor;
     ItemRetrievalThread *mItemRetrievalThread;
     QProcess *mDatabaseProcess;
     QVector< QPointer<AkonadiConnection> > mConnections;
