@@ -64,6 +64,7 @@ void FetchHelper::init()
   mMTimeRequested = false;
   mExternalPayloadSupported = false;
   mRemoteRevisionRequested = false;
+  mIgnoreErrors = false;
 }
 
 void FetchHelper::setStreamParser( ImapStreamParser *parser )
@@ -224,8 +225,16 @@ bool FetchHelper::parseStream( const QByteArray &responseIdentifier )
     retriever.setScope( mScope );
     retriever.setRetrieveParts( payloadList );
     retriever.setRetrieveFullPayload( mFullPayload );
-    if ( !retriever.exec() ) { // There we go, retrieve the missing parts from the resource.
-      throw HandlerException( QString::fromLatin1("Unable to fetch item from backend (collection %1, resource %2)").arg(mConnection->selectedCollectionId()).arg(mConnection->resourceContext().id()) );
+    if ( !retriever.exec() && !mIgnoreErrors ) { // There we go, retrieve the missing parts from the resource.
+      if (mConnection->resourceContext().isValid())
+        throw HandlerException( QString::fromLatin1("Unable to fetch item from backend (collection %1, resource %2) : %3")
+                .arg(mConnection->selectedCollectionId())
+                .arg(mConnection->resourceContext().id())
+                .arg(QString::fromLatin1(retriever.lastError())));
+      else
+        throw HandlerException( QString::fromLatin1("Unable to fetch item from backend (collection %1) : %2")
+                .arg(mConnection->selectedCollectionId())
+                .arg(QString::fromLatin1(retriever.lastError())));
     }
   }
 
@@ -306,6 +315,8 @@ bool FetchHelper::parseStream( const QByteArray &responseIdentifier )
     if ( mAncestorDepth > 0 )
       attributes.append( HandlerHelper::ancestorsToByteArray( mAncestorDepth, ancestorsForItem( parentCollectionId ) ) );
 
+    bool skipItem = false;
+
     while ( partQuery.isValid() ) {
       const qint64 id = partQuery.value( PartQueryPimIdColumn ).toLongLong();
       if ( id > pimItemId ) {
@@ -317,6 +328,12 @@ bool FetchHelper::parseStream( const QByteArray &responseIdentifier )
       QByteArray partName = Utils::variantToByteArray( partQuery.value( PartQueryNameColumn ) );
       QByteArray part = Utils::variantToByteArray( partQuery.value( PartQueryNameColumn ) );
       QByteArray data = Utils::variantToByteArray( partQuery.value( PartQueryDataColumn ) );
+      if ( mIgnoreErrors && data.isEmpty() ) {
+        //We wanted the payload, couldn't get it, and are ignoring errors. Skip the item.
+        akDebug() << id << " no payload";
+        skipItem = true;
+        break;
+      }
       bool partIsExternal = partQuery.value( PartQueryExternalColumn ).toBool();
       if ( !mExternalPayloadSupported && partIsExternal ) //external payload not supported by the client, translate the data
         data = PartHelper::translateData( data, partIsExternal );
@@ -342,6 +359,11 @@ bool FetchHelper::parseStream( const QByteArray &responseIdentifier )
       partQuery.next();
     }
 
+    if (skipItem) {
+      itemQuery.next();
+      continue;
+    }
+
     // IMAP protocol violation: should actually be the sequence number
     QByteArray attr = QByteArray::number( pimItemId ) + ' ' + responseIdentifier + " (";
     attr += ImapParser::join( attributes, " " ) + ')';
@@ -352,8 +374,9 @@ bool FetchHelper::parseStream( const QByteArray &responseIdentifier )
     itemQuery.next();
   }
 
-  // update atime
-  updateItemAccessTime();
+  // update atime (only if the payload was actually requested, otherwise a simple resource sync prevents cache clearing)
+  if ( !payloadList.isEmpty() || mFullPayload )
+    updateItemAccessTime();
 
   return true;
 }
@@ -413,6 +436,8 @@ void FetchHelper::parseCommandStream()
         mFullPayload = true;
       } else if ( buffer == AKONADI_PARAM_ANCESTORS ) {
         mAncestorDepth = HandlerHelper::parseDepth( mStreamParser->readString() );
+      } else if ( buffer == AKONADI_PARAM_IGNOREERRORS ) {
+        mIgnoreErrors = true;
       } else {
         throw HandlerException( "Invalid command argument" );
       }
