@@ -125,9 +125,10 @@ bool Akonadi::DataStore::init()
 {
   Q_ASSERT( QThread::currentThread() == QCoreApplication::instance()->thread() );
 
-  QString dbtemplate = QLatin1String(":akonadidb.xml");
 #ifdef Q_OS_WINCE
-  dbtemplate = QLatin1String(":akonadidb-mobile.xml");
+  QString dbtemplate = QLatin1String(":akonadidb-mobile.xml");
+#else
+  QString dbtemplate = QLatin1String(":akonadidb.xml");
 #endif
 
   DbInitializer::Ptr initializer = DbInitializer::createInstance( m_database, dbtemplate );
@@ -283,10 +284,11 @@ bool Akonadi::DataStore::cleanupCollection(Collection &collection)
   // remove all external payload parts
   QueryBuilder qb( Part::tableName(), QueryBuilder::Select );
   qb.addColumn( Part::dataFullColumnName() );
-  qb.addValueCondition( Part::externalFullColumnName(), Query::Equals, true );
-  qb.addValueCondition( Part::dataFullColumnName(), Query::IsNot, QVariant() );
   qb.addJoin( QueryBuilder::InnerJoin, PimItem::tableName(), Part::pimItemIdFullColumnName(), PimItem::idFullColumnName() );
   qb.addJoin( QueryBuilder::InnerJoin, Collection::tableName(), PimItem::collectionIdFullColumnName(), Collection::idFullColumnName() );
+  qb.addValueCondition( Collection::idFullColumnName(), Query::Equals, collection.id() );
+  qb.addValueCondition( Part::externalFullColumnName(), Query::Equals, true );
+  qb.addValueCondition( Part::dataFullColumnName(), Query::IsNot, QVariant() );
   if ( !qb.exec() )
     return false;
 
@@ -464,6 +466,26 @@ void DataStore::activeCachePolicy(Collection & col)
   col.setCachePolicyLocalParts( QLatin1String("ALL") );
 }
 
+QVector<Collection> DataStore::virtualCollections( const PimItem& item )
+{
+  QueryBuilder qb( CollectionPimItemRelation::tableName(), QueryBuilder::Select );
+  qb.addJoin( QueryBuilder::InnerJoin, Collection::tableName(),
+              Collection::idFullColumnName(), CollectionPimItemRelation::leftFullColumnName() );
+  Q_FOREACH ( const QString &columnName, Collection::fullColumnNames() ) {
+    qb.addColumn( columnName  );
+  }
+  qb.addValueCondition( CollectionPimItemRelation::rightFullColumnName(), Query::Equals, item.id() );
+
+  if ( !qb.exec() ) {
+    akDebug() << "Error during selection of records from table CollectionPimItemRelation"
+      << qb.query().lastError().text();
+    return QVector<Collection>();
+  }
+
+  return Collection::extractResult( qb.query() );
+}
+
+
 /* --- MimeType ------------------------------------------------------ */
 bool DataStore::appendMimeType( const QString & mimetype, qint64 *insertId )
 {
@@ -741,4 +763,3 @@ bool Akonadi::DataStore::inTransaction() const
   return m_transactionLevel > 0;
 }
 
-#include "datastore.moc"
