@@ -21,6 +21,7 @@
 #define AKONADI_QUERYBUILDER_H
 
 #include "query.h"
+#include "dbtype.h"
 
 #include <QtCore/QPair>
 #include <QtCore/QString>
@@ -48,14 +49,6 @@ class QueryBuilder
       Delete
     };
 
-    enum DatabaseType {
-      Unknown,
-      Sqlite,
-      MySQL,
-      PostgreSQL,
-      Virtuoso
-    };
-
     /**
      * When the same table gets joined as both, Inner- and LeftJoin,
      * it will be merged into a single InnerJoin since it is more
@@ -90,7 +83,7 @@ class QueryBuilder
       Sets the database which should execute the query. Unfortunately the SQL "standard"
       is not interpreted in the same way everywhere...
     */
-    void setDatabaseType( DatabaseType type );
+    void setDatabaseType( DbType::Type type );
 
     /**
       Join a table to the query.
@@ -211,6 +204,16 @@ class QueryBuilder
      */
     void setLimit( int limit );
 
+    /**
+     * Sets the column used for identification in an INSERT statement.
+     * The default is "id", only change this on tables without such a column
+     * (usually n:m helper tables).
+     * @param column Name of the identification column, empty string to disable this.
+     * @note This only affects PostgreSQL.
+     * @see insertId()
+     */
+    void setIdentificationColumn( const QString &column );
+
     /**
       Returns the query, only valid after exec().
     */
@@ -223,22 +226,19 @@ class QueryBuilder
 
     /**
       Returns the ID of the newly created record (only valid for INSERT queries)
+      @note This will assert when being used with setIdentificationColumn() called
+      with an empty string.
       @returns -1 if invalid
     */
     qint64 insertId();
 
-    /**
-      Converts Qt database driver names into database types.
-    */
-    static DatabaseType qsqlDriverNameToDatabaseType( const QString &driverName );
-
   private:
     QString bindValue( const QVariant &value );
     QString buildWhereCondition( const Query::Condition &cond );
 
   private:
     QString mTable;
-    DatabaseType mDatabaseType;
+    DbType::Type mDatabaseType;
     QHash<ConditionType, Query::Condition> mRootCondition;
     QSqlQuery mQuery;
     QueryType mType;
@@ -247,6 +247,7 @@ class QueryBuilder
     QVector<QPair<QString, Query::SortOrder> > mSortColumns;
     QStringList mGroupColumns;
     QVector<QPair<QString, QVariant> > mColumnValues;
+    QString mIdentificationColumn;
 
     // we must make sure that the tables are joined in the correct order
     // QMap sorts by key which might invalidate the queries
