@@ -251,16 +251,27 @@ void StorageJanitor::verifyExternalParts()
   // list all parts from the db which claim to have an associated file
   QueryBuilder qb( Part::tableName(), QueryBuilder::Select );
   qb.addColumn( Part::dataColumn() );
+  qb.addColumn( Part::pimItemIdColumn() );
+  qb.addColumn( Part::idColumn() );
   qb.addValueCondition( Part::externalColumn(), Query::Equals, true );
   qb.addValueCondition( Part::dataColumn(), Query::IsNot, QVariant() );
   qb.exec();
   while ( qb.query().next() ) {
     const QString partPath = qb.query().value( 0 ).toString();
+    const Entity::Id pimItemId = qb.query().value( 1 ).value<Entity::Id>();
+    const Entity::Id id = qb.query().value( 2 ).value<Entity::Id>();
     if ( existingFiles.contains( partPath ) ) {
       usedFiles.insert( partPath );
     } else {
-      inform( QLatin1Literal( "Missing external file: " ) + partPath );
-      // TODO: fix this, by clearing the data column?
+      inform( QLatin1Literal( "Cleaning up missing external file: " ) + partPath + QLatin1Literal( " for item: " ) + QString::number( pimItemId ) + QLatin1Literal( " on part: " ) + QString::number( id ) );
+
+      Part part;
+      part.setId( id );
+      part.setPimItemId( pimItemId );
+      part.setData( QByteArray() );
+      part.setDatasize( 0 );
+      part.setExternal( false );
+      part.update();
     }
   }
   inform( QLatin1Literal( "Found " ) + QString::number( usedFiles.size() ) + QLatin1Literal( " external parts." ) );
@@ -316,24 +327,26 @@ void StorageJanitor::findDirtyObjects()
 
 void StorageJanitor::vacuum()
 {
-  const QString driverName = DataStore::self()->database().driverName();
-  if( ( driverName == QLatin1String( "QMYSQL" ) ) || ( driverName == QLatin1String( "QPSQL" ) ) ) {
+  const DbType::Type dbType = DbType::type( DataStore::self()->database() );
+  if( dbType == DbType::MySQL || dbType == DbType::PostgreSQL ) {
     inform( "vacuuming database, that'll take some time and require a lot of temporary disk space..." );
     Q_FOREACH ( const QString &table, Akonadi::allDatabaseTables() ) {
       inform( QString::fromLatin1( "optimizing table %1..." ).arg( table ) );
 
       QString queryStr;
-      if ( driverName == QLatin1String( "QMYSQL" ) ) {
+      if ( dbType == DbType::MySQL ) {
         queryStr = QLatin1Literal( "OPTIMIZE TABLE " ) + table;
-      } else {
+      } else if ( dbType == DbType::PostgreSQL ) {
         queryStr = QLatin1Literal( "VACUUM FULL ANALYZE " ) + table;
+      } else {
+        continue;
       }
       QSqlQuery q( DataStore::self()->database() );
       if ( !q.exec( queryStr ) ) {
         akError() << "failed to optimize table" << table << ":" << q.lastError().text();
       }
     }
-      inform( "vacuum done" );
+    inform( "vacuum done" );
   } else {
     inform( "Vacuum not supported for this database backend." );
   }
