@@ -24,7 +24,8 @@
 #include <QMetaType>
 #include <QVariant>
 
-Q_DECLARE_METATYPE(QList<int>)
-Q_DECLARE_METATYPE(QList<QList<QVariant> >)
+typedef QVector<QList<QVariant> > XesamVariantListVector;
+Q_DECLARE_METATYPE(QList<uint>)
+Q_DECLARE_METATYPE(QVector<QList<QVariant> >)
 
 #endif
