@@ -42,6 +42,10 @@ AkApplication::AkApplication(int & argc, char ** argv) :
   sInstance = this;
 }
 
+AkApplication::~AkApplication()
+{
+}
+
 void AkApplication::init()
 {
   akInit( QString::fromLatin1( mArgv[ 0 ] ) );
@@ -140,5 +144,3 @@ void AkApplication::setInstanceIdentifier(const QString& instanceId)
   sInstance->mInstanceId = instanceId;
 }
 
-
-#include "akapplication.moc"
